@@ -8,10 +8,10 @@
 #'   [`new_data()`].
 #'
 #' @param grid A data frame representing the data grid, or an object of class
-#'   `ggeffects`, as returned by `ggpredict()` and others.
+#'   `ggeffects`, as returned by `predict_response()`.
 #' @param model The model for which to compute partial residuals. The data grid
 #'   `grid` should match to predictors in the model.
-#' @param pred_name The name of the focal predictor, for which partial residuals
+#' @param predictor_name The name of the focal predictor, for which partial residuals
 #'   are computed.
 #' @param protect_names Logical, if `TRUE`, preserves column names from the
 #'   `ggeffects` objects that is used as `grid`.
@@ -43,7 +43,7 @@
 #' d <- data.frame(x, y, z)
 #' model <- lm(y ~ x + z, data = d)
 #'
-#' pr <- ggpredict(model, c("x [all]", "z"))
+#' pr <- predict_response(model, c("x [all]", "z"))
 #' head(residualize_over_grid(pr, model))
 #' @export
 residualize_over_grid <- function(grid, model, ...) {
@@ -54,13 +54,13 @@ residualize_over_grid <- function(grid, model, ...) {
 
 #' @rdname residualize_over_grid
 #' @export
-residualize_over_grid.data.frame <- function(grid, model, pred_name, ...) {
+residualize_over_grid.data.frame <- function(grid, model, predictor_name, ...) {
 
   old_d <- insight::get_predictors(model)
   fun_link <- insight::link_function(model)
   inv_fun <- insight::link_inverse(model)
-  predicted <- grid[[pred_name]]
-  grid[[pred_name]] <- NULL
+  predicted <- grid[[predictor_name]]
+  grid[[predictor_name]] <- NULL
 
   is_fixed <- sapply(grid, function(x) length(unique(x))) == 1
   grid <- grid[, !is_fixed, drop = FALSE]
@@ -105,10 +105,10 @@ residualize_over_grid.data.frame <- function(grid, model, pred_name, ...) {
     return(NULL)
   }
 
-  points <- grid[idx, , drop = FALSE]
-  points[[pred_name]] <- inv_fun(fun_link(predicted[idx]) + res) # add errors
+  my_points <- grid[idx, , drop = FALSE]
+  my_points[[predictor_name]] <- inv_fun(fun_link(predicted[idx]) + res) # add errors
 
-  points
+  my_points
 }
 
 
@@ -121,20 +121,22 @@ residualize_over_grid.ggeffects <- function(grid, model, protect_names = TRUE, .
 
   colnames(new_d)[colnames(new_d) %in% c("x", "group", "facet", "panel")] <- attr(grid, "terms")
 
-  points <- residualize_over_grid(new_d, model, pred_name = "predicted", ...)
+  my_points <- residualize_over_grid(new_d, model, predictor_name = "predicted", ...)
 
-  if (protect_names && !is.null(points)) {
+  if (protect_names && !is.null(my_points)) {
     colnames_gge <- c("x", "group", "facet", "panel")
     colnames_orig <- attr(grid, "terms")
     for (i in seq_along(colnames_orig)) {
-      colnames(points)[colnames(points) == colnames_orig[i]] <- colnames_gge[i]
+      colnames(my_points)[colnames(my_points) == colnames_orig[i]] <- colnames_gge[i]
     }
   }
 
-  points
+  my_points
 }
 
 
+# utilities --------------------------------------------------------------------
+
 
 .is_grid <- function(df) {
   unq <- lapply(df, unique)
@@ -148,11 +150,10 @@ residualize_over_grid.ggeffects <- function(grid, model, protect_names = TRUE, .
 
   res <- merge(df, df2, by = colnames(df), all = TRUE)
 
-  return(sum(res$..1) == sum(df2$..1))
+  sum(res$..1) == sum(df2$..1)
 }
 
 
-
 .closest <- function(x, target, best_match) {
   if (is.numeric(x)) {
     # AD <- outer(x, target, FUN = function(x, y) abs(x - y))
@@ -170,7 +171,6 @@ residualize_over_grid.ggeffects <- function(grid, model, protect_names = TRUE, .
 }
 
 
-
 .validate_num <- function(x) {
   if (!is.numeric(x)) {
     x <- as.numeric(as.character(x))
